@@ -12,7 +12,7 @@ use Aniki::Schema;
 use Aniki::QueryBuilder;
 use Aniki::QueryBuilder::Canonical;
 
-our $VERSION = '0.85';
+our $VERSION = '0.86';
 
 use SQL::Maker::SQLType qw/sql_type/;
 use DBIx::Handler;
@@ -650,7 +650,7 @@ __TRACE__
 
 sub DEMOLISH {
     my $self = shift;
-    $self->handler->disconnect();
+    $self->handler->disconnect() if $self->handler;
 }
 
 __PACKAGE__->meta->make_immutable();
